@@ -395,14 +395,17 @@ on_clickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 void
 on_addclickall_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	GtkWidget *clickallmenu, *abutton;
+        GtkWidget *writemenu, *clickallmenu;
 
-	abutton = gtk_ui_manager_get_widget
-		(ui_manager, "/ToolBar/Write");
-	g_signal_emit_by_name (G_OBJECT (abutton), "clicked");
-	clickallmenu = gtk_ui_manager_get_widget
-		(ui_manager, "/MainMenu/EditMenu/Click All");
-	g_signal_emit_by_name (G_OBJECT (clickallmenu), "activate");
+	// This part does the write (equivalent to Ctrl-W)
+	writemenu = gtk_ui_manager_get_widget 
+	  (ui_manager, "/MainMenu/EditMenu/Write"); 
+	g_signal_emit_by_name (G_OBJECT (writemenu), "activate"); 
+
+	// This part does the Click All (equivalent to Ctrl-K)
+ 	clickallmenu = gtk_ui_manager_get_widget 
+ 		(ui_manager, "/MainMenu/EditMenu/Click All"); 
+ 	g_signal_emit_by_name (G_OBJECT (clickallmenu), "activate"); 
 }
 
 /* show/hide the toolbar */
