@@ -1,7 +1,8 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2012 - 2013 Andy Stewart <andystewart@comcast.net>
+   Copyright (C) 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -47,9 +48,9 @@ config_create (void)
 	preferences.EW = 1;
 	preferences.units = 1;
 	preferences.bands = g_strdup
-("0.136,1.8,3.5,5.2,7,10,14,18,21,24,28,50,70,144,222,420,902,1240,2300,3300,5650,10000,24000,47000,75500,120000,142000,241000,300000");
+("0.136,0.501,1.8,3.5,5.2,7,10,14,18,21,24,28,50,70,144,222,420,902,1240,2300,3300,5650,10000,24000,47000,75500,120000,142000,241000,300000");
 	preferences.modes = g_strdup
-("SSB,CW,FM,AM,ASCI,ATV,CLO,FAX,GTOR,HELL,HFSK,JT44,JT6M,MFSK8,MFSK16,MTTY,MT63,OLIVIA,PAC,PAC2,PAC3,PCW,PKT,PSK31,PSK63,PSK125,Q15,RTTY,SSTV,THRB,TOR");
+("SSB,CW,FM,AM,PSK31,RTTY,HELL,AMTORFEC,ASCI,ATV,CHIP64,CHIP128,CLO,CONTESTI,DSTAR,DOMINO,DOMINOF,FAX,FMHELL,FSK31,FSK441,GTOR,HELL80,HFSK,JT44,JT4A,JT4B,JT4C,JT4D,JT4E,JT4F,JT4G,JT65,JT65A,JT65B,JT65C,JT6M,MFSK8,MFSK16,MT63,OLIVIA,PAC,PAC2,PAC3,PAX,PAX2,PCW,PKT,PSK10,PSK63,PSK63F,PSK125,PSKAM10,PSKAM31,PSKAM50,PSKFEC31,PSKHELL,Q15,QPSK31,QPSK63,QPSK125,ROS,RTTYM,SSTV,THRB,THOR,THRBX,TOR,VOI,WINMOR,WSPR");
 	preferences.bandseditbox = 0;
 	preferences.modeseditbox = 0;
 	preferences.bandoptionmenu = 0;
@@ -137,6 +138,7 @@ config_create (void)
 	preferences.b4width = 500;
 	preferences.b4height = 300;
 	preferences.saveasadif = 0;
+	preferences.saveascabrillo = 0;
 	preferences.saveastsv2 = g_new (gint, 18);
 	preferences.saveastsv2[0] = 1;
 	preferences.saveastsv2[1] = 1;
@@ -184,19 +186,19 @@ config_create (void)
 	preferences.scorey = 300;
 	preferences.scorewidth = 500;
 	preferences.scoreheight = 300;
-	preferences.scoringbands = g_new (gint, 29);
+	preferences.scoringbands = g_new (gint, 30);
 	preferences.scoringbands[0] = 0;
-	preferences.scoringbands[1] = 1;
+	preferences.scoringbands[1] = 0;
 	preferences.scoringbands[2] = 1;
-	preferences.scoringbands[3] = 0;
-	preferences.scoringbands[4] = 1;
+	preferences.scoringbands[3] = 1;
+	preferences.scoringbands[4] = 0;
 	preferences.scoringbands[5] = 1;
 	preferences.scoringbands[6] = 1;
 	preferences.scoringbands[7] = 1;
 	preferences.scoringbands[8] = 1;
 	preferences.scoringbands[9] = 1;
 	preferences.scoringbands[10] = 1;
-	preferences.scoringbands[11] = 0;
+	preferences.scoringbands[11] = 1;
 	preferences.scoringbands[12] = 0;
 	preferences.scoringbands[13] = 0;
 	preferences.scoringbands[14] = 0;
@@ -214,6 +216,7 @@ config_create (void)
 	preferences.scoringbands[26] = 0;
 	preferences.scoringbands[27] = 0;
 	preferences.scoringbands[28] = 0;
+	preferences.scoringbands[29] = 0;
 	preferences.distqrb = 0;
 	preferences.awardswac = 0;
 	preferences.awardswas = 0;
@@ -221,6 +224,7 @@ config_create (void)
 	preferences.awardsiota = 0;
 	preferences.awardsloc = 0;
 	preferences.openurl = g_strdup ("http://www.qrz.com/db/<call>");
+	preferences.areyousure = 1;
 	preferences.initlastmsg = g_strdup ("");
 }
 
@@ -332,10 +336,10 @@ static void config_load_from_keyfile (GKeyFile *file)
 		preferences.units = preferences.units - 1;
 	preferences.bands = g_key_file_get_string (file, "general", "bands", NULL);
 	if (!preferences.bands) preferences.bands = g_strdup
-("0.136,1.8,3.5,5.2,7,10,14,18,21,24,28,50,70,144,222,420,902,1240,2300,3300,5650,10000,24000,47000,75500,120000,142000,241000,300000");
+("0.136,0.501,1.8,3.5,5.2,7,10,14,18,21,24,28,50,70,144,222,420,902,1240,2300,3300,5650,10000,24000,47000,75500,120000,142000,241000,300000");
 	preferences.modes = g_key_file_get_string (file, "general", "modes", NULL);
 	if (!preferences.modes) preferences.modes = g_strdup
-("SSB,CW,FM,AM,ASCI,ATV,CLO,FAX,GTOR,HELL,HFSK,JT44,JT6M,MFSK8,MFSK16,MTTY,MT63,OLIVIA,PAC,PAC2,PAC3,PCW,PKT,PSK31,PSK63,PSK125,Q15,RTTY,SSTV,THRB,TOR");
+("SSB,CW,FM,AM,PSK31,RTTY,HELL,AMTORFEC,ASCI,ATV,CHIP64,CHIP128,CLO,CONTESTI,DSTAR,DOMINO,DOMINOF,FAX,FMHELL,FSK31,FSK441,GTOR,HELL80,HFSK,JT44,JT4A,JT4B,JT4C,JT4D,JT4E,JT4F,JT4G,JT65,JT65A,JT65B,JT65C,JT6M,MFSK8,MFSK16,MT63,OLIVIA,PAC,PAC2,PAC3,PAX,PAX2,PCW,PKT,PSK10,PSK63,PSK63F,PSK125,PSKAM10,PSKAM31,PSKAM50,PSKFEC31,PSKHELL,Q15,QPSK31,QPSK63,QPSK125,ROS,RTTYM,SSTV,THRB,THOR,THRBX,TOR,VOI,WINMOR,WSPR");
 	preferences.typeaheadfind = g_key_file_get_integer (file, "general", "typeaheadfind", NULL);
 	if (preferences.typeaheadfind == 0)
 		preferences.typeaheadfind = 1;
@@ -355,6 +359,11 @@ static void config_load_from_keyfile (GKeyFile *file)
 	if (!preferences.openurl)
 		preferences.openurl = g_strdup ("http://www.qrz.com/db/<call>");
 
+	preferences.areyousure = g_key_file_get_integer (file, "general", "areyousure", NULL);
+	if (preferences.areyousure == 0)
+		preferences.areyousure = 1;
+	else
+		preferences.areyousure = preferences.areyousure - 1;
 	preferences.viewscoring = g_key_file_get_integer (file, "appearance", "viewscoring", NULL);
 	if (preferences.viewscoring == 0)
 		preferences.viewscoring = 1;
@@ -400,7 +409,6 @@ static void config_load_from_keyfile (GKeyFile *file)
 		preferences.clock = 0;
 	else
 		preferences.clock = preferences.clock - 1;
-
 	preferences.callsign = g_key_file_get_string (file, "personal", "callsign", NULL);
 	if (!preferences.callsign) preferences.callsign = g_strdup ("N0CALL");
 	preferences.locator = g_key_file_get_string (file, "personal", "locator", NULL);
@@ -515,17 +523,17 @@ static void config_load_from_keyfile (GKeyFile *file)
 	if (!preferences.scoringbands)
 	{
 		preferences.scoringbands[0] = 0;
-		preferences.scoringbands[1] = 1;
+		preferences.scoringbands[1] = 0;
 		preferences.scoringbands[2] = 1;
-		preferences.scoringbands[3] = 0;
-		preferences.scoringbands[4] = 1;
+		preferences.scoringbands[3] = 1;
+		preferences.scoringbands[4] = 0;
 		preferences.scoringbands[5] = 1;
 		preferences.scoringbands[6] = 1;
 		preferences.scoringbands[7] = 1;
 		preferences.scoringbands[8] = 1;
 		preferences.scoringbands[9] = 1;
 		preferences.scoringbands[10] = 1;
-		preferences.scoringbands[11] = 0;
+		preferences.scoringbands[11] = 1;
 		preferences.scoringbands[12] = 0;
 		preferences.scoringbands[13] = 0;
 		preferences.scoringbands[14] = 0;
@@ -543,6 +551,7 @@ static void config_load_from_keyfile (GKeyFile *file)
 		preferences.scoringbands[26] = 0;
 		preferences.scoringbands[27] = 0;
 		preferences.scoringbands[28] = 0;
+		preferences.scoringbands[29] = 0;
 	}
 	preferences.awardswac = g_key_file_get_integer (file, "scoring", "wac", NULL);
 	if (preferences.awardswac == 0)
@@ -627,11 +636,19 @@ static void config_load_from_keyfile (GKeyFile *file)
 		preferences.logcwidths2[17]=100;
 		preferences.logcwidths2[18]=200;	
 	}
+
 	preferences.saveasadif = g_key_file_get_integer (file, "saveas", "adif", NULL);
 	if (preferences.saveasadif == 0)
 		preferences.saveasadif = 0;
 	else
 		preferences.saveasadif = preferences.saveasadif - 1;
+
+	preferences.saveascabrillo = g_key_file_get_integer (file, "saveas", "cabrillo", NULL);
+	if (preferences.saveascabrillo == 0)
+		preferences.saveascabrillo = 0;
+	else
+		preferences.saveascabrillo = preferences.saveascabrillo - 1;
+
 	preferences.saveastsv2 = g_key_file_get_integer_list (file, "saveas", "tsvcolumns", &len, NULL);
 	if (!preferences.saveastsv2)
 	{
@@ -725,6 +742,7 @@ savepreferences (void)
 	g_key_file_set_integer (file, "general", "remoteadding", preferences.remoteadding + 1);
 	g_key_file_set_integer (file, "general", "distqrb", preferences.distqrb + 1);
 	g_key_file_set_string (file, "general", "openurl", preferences.openurl);
+	g_key_file_set_integer (file, "general", "areyousure", preferences.areyousure + 1);
 
 	g_key_file_set_integer (file, "appearance", "viewscoring", preferences.viewscoring + 1);
 	g_key_file_set_integer (file, "appearance", "viewtoolbar", preferences.viewtoolbar + 1);
@@ -778,7 +796,7 @@ savepreferences (void)
 	g_key_file_set_integer (file, "keyer", "speed", preferences.cwspeed);
 	g_key_file_set_string (file, "keyer", "initial_lastmessage", preferences.initlastmsg);
 
-	g_key_file_set_integer_list (file, "scoring", "bands", preferences.scoringbands, 29);
+	g_key_file_set_integer_list (file, "scoring", "bands", preferences.scoringbands, 30);
 	g_key_file_set_integer (file, "scoring", "wac", preferences.awardswac + 1);
 	g_key_file_set_integer (file, "scoring", "was", preferences.awardswas + 1);
 	g_key_file_set_integer (file, "scoring", "waz", preferences.awardswaz + 1);
@@ -798,6 +816,7 @@ savepreferences (void)
 	g_key_file_set_integer_list (file, "logs", "columnwidths", preferences.logcwidths2, 19);
 
 	g_key_file_set_integer (file, "saveas", "adif", preferences.saveasadif + 1);
+	g_key_file_set_integer (file, "saveas", "cabrillo", preferences.saveascabrillo + 1);
 	g_key_file_set_integer_list (file, "saveas", "tsvcolumns", preferences.saveastsv2, 18);
 	g_key_file_set_integer (file, "saveas", "tsvcalc", preferences.tsvcalc + 1);
 	g_key_file_set_integer (file, "saveas", "tsvsortbydxcc", preferences.tsvsortbydxcc + 1);
