@@ -24,6 +24,45 @@
  * dxcc.c - dxcc lookups and creation of the hashtable
  */
 
+//
+// As described on this website:
+// http://n1mm.hamdocs.com/tiki-index.php?page=Customizing+the+DXCC+List
+//
+// CTY.DAT file format
+// The format from CTY.DAT is as follows:
+// Column	Length	Description
+// 1	26	Country name terminated by a colon character.
+// 27	5	CQ zone terminated by a colon character.
+// 32	5	ITU zone terminated by a colon character.
+// 37	5	2-letter continent abbreviation terminated by a colon character.
+// 42	9	Latitude in degrees, + for North terminated by a colon character.
+// 51	9	Longitude in degrees, + for West terminated by a colon character.
+// 61	9	Local time offset from GMT terminated by a colon character.
+// 69	6	Primary DXCC Prefix terminated by a colon character.
+// next line(s)	List of prefixes assigned to that country, each one separated
+//              by a comma and terminated by a semicolon.
+// 
+// The fields are aligned in columns and spaced out for readability only.
+// It is the ":" at the end of each field that acts as a delimiter for that field.
+// 
+// Alias DXCC prefixes (including the primary one) follow on consecutive lines,
+// separated by ",". If there is more than one line, subsequent lines begin
+// with the "&" continuation character. A ";" terminates the last prefix in 
+// the list.
+// 
+// "Prefixes" which start with "=" are not prefixes, but are full callsigns
+// and seem to be exceptions to the rules.
+//
+// If the country spans multiple zones, then the prefix may be followed by a 
+// CQWW zone number in parenthesis, and it may also be followed by an ITU zone
+// number in square brackets, or both, but the CQ zone number in parenthesis
+// must precede the ITU zone number in square brackets.
+// 
+// The following special characters can be applied to an alias prefix:
+// (#) Override CQ zone where # is the zone number
+// [#] Override ITU zone where # is the zone number 
+//
+
 #include <gtk/gtk.h>
 #include <stdlib.h>
 #include <string.h>
@@ -46,7 +85,7 @@ extern preferencestype preferences;
 extern programstatetype programstate;
 extern GList *logwindowlist;
 GPtrArray *dxcc, *area;
-GHashTable *prefixes;
+GHashTable *prefixes, *full_callsign_exceptions;
 gint excitu, exccq;
 
 /* gushort: 0 - 65534, one extra element for all bands scoring */
@@ -83,6 +122,7 @@ cleanup_dxcc (void)
       g_ptr_array_free (dxcc, TRUE);
     }
   if (prefixes) g_hash_table_destroy (prefixes);
+  if (full_callsign_exceptions) g_hash_table_destroy (full_callsign_exceptions);
 
   for (i = 0; i < MAX_BANDS; i++)
     {
@@ -136,6 +176,8 @@ findpfx_in_exception (gchar * pfx)
 	  break;
 	}
     }
+
+// BOZO!!!!!!!
   if (pfx[0] == '=')
     return pfx + 1;
   return pfx;
@@ -284,16 +326,20 @@ lookupcountry_by_callsign (gchar * callsign)
 
   lookup.country = 0;
 
-  /* first check complete callsign */
-  lookup.country = GPOINTER_TO_INT(g_hash_table_lookup (prefixes, callsign));
+  /* first check complete callsign exceptions list*/
+  lookup.country = GPOINTER_TO_INT(g_hash_table_lookup (full_callsign_exceptions, callsign));
+
+  if (lookup.country == 0) {
+    /* Next, check the list of prefixes */
+    lookup.country = GPOINTER_TO_INT(g_hash_table_lookup (prefixes, callsign));
+  }
 
   if (lookup.country == 0 && (px = getpx (callsign)))
     {	/* start with full callsign and truncate it until a correct lookup */
       for (ipx = strlen (px); ipx > 0; ipx--)
 	{
 	  searchpx = g_strndup (px, ipx);
-	  lookup.country = GPOINTER_TO_INT
-	    (g_hash_table_lookup (prefixes, searchpx));
+	  lookup.country = GPOINTER_TO_INT(g_hash_table_lookup (prefixes, searchpx));
 	  if (lookup.country > 0) break;
 	}
       g_free (px);
@@ -423,6 +469,7 @@ readctydata (void)
 
   dxcc = g_ptr_array_new ();
   prefixes = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+  full_callsign_exceptions = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 
   /* first field in case hash_table_lookup returns NULL */
   dxcc_add (_("Unknown"), 0, 0, 99, 0, 0, 0, "", "");
@@ -465,7 +512,6 @@ readctydata (void)
 		    (gint)(strtod(split[6], NULL) * 10), split[7], split[8]);
 
 	  /* NOTE: split[7] is the description prefix, it is not added to the hashtable */
-	  /* Andy: not sure why this was omitted, so let's add it and see what happens. */
 	  /* With this addition, the user can enter the "callsign" like "3D2/R" and the */
 	  /* scoring window locator box will show the proper DXCC entity, even though   */
 	  /* this isn't a "real" callsign.  AMS 24-feb-2013 */
@@ -477,19 +523,25 @@ readctydata (void)
 		  tmp[i] = toupper(split[7][i]);
 		}
 	      tmp[i] = '\0';
-/*	      printf("DEBUG: adding %s to hash table as country #%0d\n", tmp, programstate.countries); */
 	      g_hash_table_insert (prefixes, g_strdup (tmp), GINT_TO_POINTER (programstate.countries));	      
 	    }
 
 	  /* split up the second line */
+	  /* The second line is made up of prefixes AND exceptions which start with '=' */
+	  /* As of 2.0.11, there are two hashes, one for prefixes and one for           */
+	  /* callsign exceptions due to a recently discovered bug.                      */
+
 	  pfxsplit = g_strsplit (split[8], ",", 0);
-	  /* exception list */
 	  for (ipfx = 0;; ipfx++)
 	  {
 	    if (!pfxsplit[ipfx]) break;
+
 	    pfx = findpfx_in_exception (pfxsplit[ipfx]);
-/*	    printf("DEBUG: adding %s to hash table as country #%d\n", pfx, programstate.countries);*/
-	    g_hash_table_insert (prefixes, g_strdup (pfx), GINT_TO_POINTER (programstate.countries));
+	    if (!strncmp(pfxsplit[ipfx], "=", 1)) {
+	      g_hash_table_insert (full_callsign_exceptions, g_strdup (pfx), GINT_TO_POINTER (programstate.countries));
+	    } else {
+	      g_hash_table_insert (prefixes, g_strdup (pfx), GINT_TO_POINTER (programstate.countries));
+	    }
 	  }
 	  g_strfreev (pfxsplit);
 	  programstate.countries++;
