@@ -1,6 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2012 - 2013 Andy Stewart <andystewart@comcast.net>
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -54,9 +55,13 @@ handle_email (GtkAboutDialog *about, const char *link, gpointer data)
 void
 on_menu_about_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	const gchar *authors[] = { "Joop Stakenborg PG4I <pg4i@amsat.org>",
+	const gchar *authors[] = { "Andy Stewart KB1OIQ <andystewart@comcast.net>",
+		"Joop Stakenborg PG4I <pg4i@amsat.org>",
 		"Stephane Fillod F8CFE <f8cfe@free.fr>", NULL };
-	const gchar *documenters[] = {"Joop Stakenborg PG4I <pg4i@amsat.org>", NULL };
+	const gchar *documenters[] = { "Andy Stewart KB1OIQ <andystewart@comcast.net>",
+				       "Joop Stakenborg PG4I <pg4i@amsat.org>",
+				       "Chris Story K6RWJ <ke6rwj@gmail.com>", 
+				       NULL };
 
 	GdkPixbuf *pixbuf = create_pixbuf ("xlog.png");
 
@@ -77,7 +82,7 @@ on_menu_about_activate (GtkMenuItem * menuitem, gpointer user_data)
 		"authors", authors,
 		"documenters", documenters,
 		"comments", str,
-		"copyright", "Copyright (C) 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>",
+		"copyright", "Copyright (C) 2012 - 2013 Andy Stewart <andystewart@comcast.net>\n 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>",
 		"license",
 "Xlog is free software: you can redistribute it and/or modify "
 "it under the terms of the GNU General Public License as published by "
@@ -95,7 +100,7 @@ on_menu_about_activate (GtkMenuItem * menuitem, gpointer user_data)
 "Full text of the GPL can be seen in the xlog handbook under "
 "the chapter \"License\".",
 		"wrap-license", TRUE,
-		"website", "http://pg4i.chronos.org.uk/linux/xlog.html",
+		"website", "http://www.nongnu.org/xlog",
 		"website-label", "Xlog Homepage",
 //		"logo-icon-name", "xlog",
 		"logo", pixbuf,
