@@ -37,6 +37,7 @@
 #include "log.h"
 #include "xlog_enum.h"
 #include "main.h"
+#include "gui_warningdialog.h"
 
 extern programstatetype programstate;
 extern GtkWidget *mainnotebook;
@@ -115,7 +116,7 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 		*dupecheckstatusbar_hbox, *dupecheckstatusbar, *dupecheckprogressbar,
 		*dupelistdialog, *dupelistdialogvbox, *dupelistlabel,
 		*dupelisthseparator, *dupelistscrolledwindow, *dupelisttreeview,
-		*duperesultdialog, *duperesultlabel, *cancel_button;
+		*cancel_button;
 	GdkPixbuf *dupelistdialog_icon_pixbuf;
 	GList *dupelist = NULL;
 	GSList *duperadiobutton_group = NULL;
@@ -138,7 +139,7 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 	if (page >= 0)
 	{
 		dupecheckdialog = gtk_dialog_new_with_buttons (_("xlog - dupecheck"),
-			GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
+			GTK_WINDOW(mainwindow), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
 		cancel_button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
 		gtk_dialog_add_action_widget
@@ -292,7 +293,7 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 			dupelistdialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 			gtk_window_set_title
 				(GTK_WINDOW (dupelistdialog), _("xlog - dupe results"));
-			gtk_window_set_default_size (GTK_WINDOW (dupelistdialog), 500, 300);
+			gtk_window_set_default_size (GTK_WINDOW (dupelistdialog), 600, 300);
 			dupelistdialog_icon_pixbuf = create_pixbuf ("xlog.png");
 			if (dupelistdialog_icon_pixbuf)
 				{
@@ -304,6 +305,14 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 			gtk_container_add
 				(GTK_CONTAINER (dupelistdialog), dupelistdialogvbox);
 
+			dupelistlabel = gtk_label_new
+				(_("Select an entry to highlight the corresponding entry in the main window"));
+			gtk_box_pack_start
+				(GTK_BOX (dupelistdialogvbox), dupelistlabel, FALSE, FALSE, 0);
+			dupelisthseparator = gtk_hseparator_new ();
+			gtk_box_pack_start (GTK_BOX (dupelistdialogvbox),
+				dupelisthseparator, FALSE, FALSE, 0);
+
 			/* create a treeview */
 			dupelistscrolledwindow = gtk_scrolled_window_new (NULL, NULL);
 			gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW
@@ -311,8 +320,6 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 				GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 			gtk_box_pack_start (GTK_BOX (dupelistdialogvbox),
 				dupelistscrolledwindow, TRUE, TRUE, 0);
-			gtk_box_reorder_child (GTK_BOX (dupelistdialogvbox),
-				dupelistscrolledwindow, 0);
 			dupestore = gtk_list_store_new (7, G_TYPE_STRING, G_TYPE_STRING,
 				G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 				G_TYPE_STRING);
@@ -388,11 +395,9 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 			gtk_box_pack_start (GTK_BOX (dupelistdialogvbox),
 				dupelisthseparator, FALSE, FALSE, 0);
 			dupelistlabel = gtk_label_new
-				(_("Select an entry to highlight the corresponding entry in the main window"));
+				(_("This window will not update when you modify QSO's"));
 			gtk_box_pack_start
 				(GTK_BOX (dupelistdialogvbox), dupelistlabel, FALSE, FALSE, 0);
-			gtk_label_set_line_wrap (GTK_LABEL (dupelistlabel), TRUE);
-			gtk_misc_set_padding (GTK_MISC (dupelistlabel), 0, 5);
 
 			dupemodel = gtk_tree_view_get_model (GTK_TREE_VIEW(dupelisttreeview));
 			page = savedpage;
@@ -420,19 +425,20 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 					{
 						gtk_tree_model_get (logmodel, &iter, BAND, &band, -1);
 						enumband = freq2enum (band);
-						str = g_strdup_printf ("%d/ ", enumband);
+						str = g_strdup_printf ("%d/", enumband);
 						temp = g_strconcat (temp, str, NULL);
 						g_free (str);
 					}
 					if (!programstate.notdupecheckmode)
 					{
 						gtk_tree_model_get (logmodel, &iter, MODE, &mode, -1);
-						enummode = freq2enum (mode);
+						enummode = mode2enum (mode);
 						str = g_strdup_printf ("%d", enummode);
 						temp = g_strconcat (temp, str, NULL);
 						g_free (str);
 					}
 					dupestr = g_strdup (temp);
+
 					/* check every callsign against the dupelist */
 					count = 0;
 					for (step = 0; step < g_list_length(dupelist); step++)
@@ -487,18 +493,8 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 				gtk_widget_show_all (dupelistdialog);
 			else
 			{ /* no dupe found, show a message */
-				duperesultdialog = gtk_dialog_new_with_buttons
-					(_("xlog - dupe results"),
-					GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
-					GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
-				gtk_widget_set_size_request (duperesultdialog, 350, 150);
-				duperesultlabel = gtk_label_new (_("No dupes found!"));
-				gtk_container_add (GTK_CONTAINER
-					(GTK_DIALOG (duperesultdialog)->vbox), duperesultlabel);
-				gtk_widget_destroy (dupelistdialog);
-				gtk_widget_show_all (duperesultdialog);
-				gtk_dialog_run (GTK_DIALOG (duperesultdialog));
-				gtk_widget_destroy (duperesultdialog);
+				warningdialog (_("xlog - dupe results"),
+				_("No dupes found!"), "gtk-info");
 			}
 		} /* GTK_RESPONSE_OK */
 	} /* page >= 0 */
