@@ -1,7 +1,8 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
-   Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
+   Copyright (C) 2012 Andy Stewart <andystewart@comcast.net>
+   Copyright (C) 2001 - 2010 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
 
@@ -23,7 +24,7 @@
 /* gui_exportdialog.c - creation and destruction of the exportdialog 
  *
  * this shows a savedialog with an optionmenu added for the supported filetypes:
- * adif, cabrillo, EDI, trlog (tlf) and tab separated value (TSV) for
+ * adif v2, cabrillo v3, EDI, trlog (tlf) and tab separated value (TSV) for
  * glabels. There are also 2 entries which you can use to save part of the log.
  * We do a check if the first QSO number is lower than the last and display a
  * warning dialog in case we overwrite a previously created log.
@@ -62,8 +63,8 @@ on_menu_export_activate (GtkMenuItem * menuitem, gpointer user_data)
 	if (page >= 0)
 	{
 		exportdialog = gtk_file_chooser_dialog_new (_("xlog - export"),
-    	GTK_WINDOW(mainwindow), GTK_FILE_CHOOSER_ACTION_SAVE, GTK_STOCK_CANCEL, 
-		GTK_RESPONSE_CANCEL, GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
+		  GTK_WINDOW(mainwindow), GTK_FILE_CHOOSER_ACTION_SAVE, GTK_STOCK_CANCEL, 
+		  GTK_RESPONSE_CANCEL, GTK_STOCK_OK, GTK_RESPONSE_OK, NULL);
 
 		gtk_window_set_modal (GTK_WINDOW(exportdialog), TRUE);
 		gtk_window_set_destroy_with_parent (GTK_WINDOW(exportdialog), TRUE);
@@ -74,8 +75,8 @@ on_menu_export_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 		filemenu = gtk_combo_box_new_text ();
 		gtk_box_pack_start (GTK_BOX (hbox), filemenu, FALSE, FALSE, 15);
-		gtk_combo_box_append_text (GTK_COMBO_BOX (filemenu), "adif");
-		gtk_combo_box_append_text (GTK_COMBO_BOX (filemenu), "cabrillo");
+		gtk_combo_box_append_text (GTK_COMBO_BOX (filemenu), "adif v2");
+		gtk_combo_box_append_text (GTK_COMBO_BOX (filemenu), "cabrillo v3");
 		gtk_combo_box_append_text (GTK_COMBO_BOX (filemenu), "EDI");
 		gtk_combo_box_append_text (GTK_COMBO_BOX (filemenu), "TSV");
 		gtk_combo_box_set_active (GTK_COMBO_BOX (filemenu), 0);
@@ -83,12 +84,12 @@ on_menu_export_activate (GtkMenuItem * menuitem, gpointer user_data)
 		qsolabel = gtk_label_new (_("Export QSO:"));
 		gtk_box_pack_start (GTK_BOX (hbox), qsolabel, FALSE, FALSE, 15);
 		lowqsoentry = gtk_entry_new ();
-		gtk_widget_set_size_request (lowqsoentry, 50, -1);
+		gtk_widget_set_size_request (lowqsoentry, 60, -1);
 		gtk_box_pack_start (GTK_BOX (hbox), lowqsoentry, FALSE, FALSE, 15);
 		dash = gtk_label_new (_("to"));
 		gtk_box_pack_start (GTK_BOX (hbox), dash, FALSE, FALSE, 15);
 		highqsoentry = gtk_entry_new ();
-		gtk_widget_set_size_request (highqsoentry, 50, -1);
+		gtk_widget_set_size_request (highqsoentry, 60, -1);
 		gtk_box_pack_start (GTK_BOX (hbox), highqsoentry, FALSE, FALSE, 15);
 		
 		logwindow = g_list_nth_data (logwindowlist, page);
@@ -115,10 +116,10 @@ on_menu_export_activate (GtkMenuItem * menuitem, gpointer user_data)
 			switch (index)
 			{
 			case 0:
-				type = TYPE_ADIF;
+				type = TYPE_ADIF2;
 				break;
 			case 1:
-				type = TYPE_CABRILLO;
+				type = TYPE_CABRILLO3;
 				break;
 			case 2:
 				type = TYPE_EDI;
@@ -130,16 +131,15 @@ on_menu_export_activate (GtkMenuItem * menuitem, gpointer user_data)
 				type = 0;
 			}
 
-			sellog = gtk_file_chooser_get_filename
-				(GTK_FILE_CHOOSER (exportdialog));
+			sellog = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (exportdialog));
 			temp = gtk_editable_get_chars (GTK_EDITABLE (lowqsoentry), 0, -1);
 			lowqso = atoi (temp);
 			temp = gtk_editable_get_chars (GTK_EDITABLE (highqsoentry), 0, -1);
 			highqso = atoi (temp);
 			logwindow = g_list_nth_data (logwindowlist,
 				gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook)));
-			if (lowqso > highqso || highqso > logwindow->qsos)
-update_statusbar(_("Cannot export log: invalid entry for first and/or last QSO"));
+			if ((lowqso > highqso) ||( highqso > logwindow->qsos))
+				update_statusbar(_("Cannot export log: invalid entry for first and/or last QSO"));
 			else if (!g_file_test(sellog, G_FILE_TEST_EXISTS))
 			{
 				savelog (logwindow, sellog, type, lowqso, highqso);
@@ -168,8 +168,8 @@ update_statusbar(_("Cannot export log: invalid entry for first and/or last QSO")
 				{
 					logwindow = g_list_nth_data (logwindowlist,
 						gtk_notebook_get_current_page(GTK_NOTEBOOK (mainnotebook)));
-					if (lowqso > highqso || highqso > logwindow->qsos)
-update_statusbar (_("Cannot export log: invalid entry for first and/or last QSO"));
+					if ((lowqso > highqso) || (highqso > logwindow->qsos))
+					  update_statusbar (_("Cannot export log: invalid entry for first and/or last QSO"));
 					else
 					{
 						savelog (logwindow, sellog, type, lowqso, highqso);
