@@ -1,6 +1,7 @@
 /*
 
    xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2012 Andy Stewart <andystewart@comcast.net>
    Copyright (C) 2001 - 2008 Joop Stakenborg <pg4i@amsat.org>
 
    This file is part of xlog.
@@ -80,7 +81,7 @@ notebook_append_awardpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook, co
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING);
+		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 	awardtreeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(awardmodel));
 	gtk_tree_view_set_search_column (GTK_TREE_VIEW (awardtreeview), -1);
 	g_object_unref (G_OBJECT (awardmodel));
@@ -94,6 +95,12 @@ notebook_append_awardpage (GtkWidget *scorewindow, GtkWidget *awardsnotebook, co
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_2190]);
 
+	column = gtk_tree_view_column_new_with_attributes
+		("0.501", renderer, "text", BAND_560, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_560]);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("1.8", renderer, "text", BAND_160, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (awardtreeview), column);
@@ -381,7 +388,7 @@ create_scorewindow (void)
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (scorewindow), hbox);
 	vboxleft = gtk_vbox_new (FALSE, 0);
-	gtk_widget_set_size_request (vboxleft, 200, -1);
+	gtk_widget_set_size_request (vboxleft, 250, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), vboxleft, FALSE, FALSE, 0);
 
 	/* locator information frame */
@@ -391,10 +398,11 @@ create_scorewindow (void)
 	gtk_container_add (GTK_CONTAINER (locatorframe), locatorvbox);
 	locatorlabel = gtk_label_new ("");
 	gtk_box_pack_start (GTK_BOX (locatorvbox), locatorlabel, FALSE, FALSE, 0);
-	temp = g_strdup_printf ("<b>%s</b>", _("Locator"));
+	temp = g_strdup_printf ("<b> %s </b>", _("Locator"));
 	locatorframelabel = gtk_label_new (NULL);
 	gtk_label_set_markup (GTK_LABEL (locatorframelabel), temp);
 	gtk_frame_set_label_widget (GTK_FRAME (locatorframe), locatorframelabel);
+	gtk_widget_set_size_request (locatorframelabel, 120, 10);
 
 	/* dxcc information frame */
 	dxccframe = gtk_frame_new (NULL);
@@ -421,7 +429,7 @@ create_scorewindow (void)
 	gtk_box_pack_start (GTK_BOX (dxccvbox), dxcclabel5, FALSE, FALSE, 0);
 	
 	dxccframelabel = gtk_label_new (NULL);
-	gtk_label_set_markup (GTK_LABEL (dxccframelabel), "<b>DXCC</b>");
+	gtk_label_set_markup (GTK_LABEL (dxccframelabel), "<b>VERYBIGCALLSIGN</b>");
 	gtk_frame_set_label_widget (GTK_FRAME (dxccframe), dxccframelabel);
 	gtk_label_set_line_wrap (GTK_LABEL (dxcclabel1), TRUE);
 	gtk_widget_set_size_request (dxcclabel1, -1, 60);
@@ -447,7 +455,7 @@ create_scorewindow (void)
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
 		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-		G_TYPE_STRING, G_TYPE_STRING);
+		G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 	countrytreeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL(model));
 	gtk_tree_view_set_search_column (GTK_TREE_VIEW (countrytreeview), -1);
 	g_object_unref (G_OBJECT (model));
@@ -465,6 +473,12 @@ create_scorewindow (void)
 	gtk_tree_view_column_set_visible
 		(column, preferences.scoringbands[BAND_2190]);
 
+	column = gtk_tree_view_column_new_with_attributes
+		("0.501", renderer, "text", BAND_560 + 1, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
+	gtk_tree_view_column_set_visible
+		(column, preferences.scoringbands[BAND_560]);
+
 	column = gtk_tree_view_column_new_with_attributes
 		("1.8", renderer, "text", BAND_160 + 1, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (countrytreeview), column);
