@@ -150,10 +150,10 @@ gchar *band_enum2bandchar (gint band_enum)
 /* return freq in kHz from a given frequency string */
 gchar *freq2khz (gchar * str)
 {
-	gchar *p, *p1, *temp;
+	gchar *p, *temp;
 	gchar *pEnd;
 	gchar temp_mhz[7];
-	gdouble freq, freq1, freq2, freq3;
+	gdouble freq, freq1;
 
 	temp  = g_strdup (str);
 	p = g_strrstr (temp, ".");
